#
# spec file for package fipscheck
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libfipscheck1 

Name:           fipscheck
Version:        1.4.1
Release:        lp150.2.3.1
Summary:        A library for integrity verification of FIPS validated modules
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://fedorahosted.org/fipscheck/
Source0:        http://fedorahosted.org/releases/f/i/%{name}/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         openssl-1_1-port.patch
Patch1:         fipscheck-fips.h_not_needed.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libopenssl-devel >= 0.9.8j
Requires:       %{lname} = %{version}

%global soversion 1.2.1
%global somajor 1

%description
FIPSCheck is a library for integrity verification of FIPS validated
modules. The package also provides helper binaries for creation and
verification of the HMAC-SHA256 checksum files.

%package -n %lname
Summary:        Library files for %{name}
Group:          System/Libraries
Requires:       %{_bindir}/fipscheck

%description -n %lname
This package contains the FIPSCheck library.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
This package contains development files for %{name}.

%prep
%setup -q
if pkg-config --atleast-version=1.1 openssl; then
%patch0 -p1
fi
%patch1 -p1

%build
%configure --disable-static --libdir=/%{_lib}

make %{?_smp_mflags} LDFLAGS="-Wl,-z,relro"

# Add generation of HMAC checksums of the final stripped binaries
%define __spec_install_post \
    %{?__debug_package:%{__debug_install_post}} \
    %{__arch_install_post} \
    %{__os_install_post} \
    $RPM_BUILD_ROOT%{_bindir}/fipshmac $RPM_BUILD_ROOT%{_bindir}/fipscheck \
    $RPM_BUILD_ROOT%{_bindir}/fipshmac $RPM_BUILD_ROOT/%{_lib}/libfipscheck.so.%{soversion} \
    ln -s .libfipscheck.so.%{soversion}.hmac $RPM_BUILD_ROOT/%{_lib}/.libfipscheck.so.%{somajor}.hmac \
%{nil}

%install
%make_install
find $RPM_BUILD_ROOT -type f -name "*.la" -delete

mkdir -p $RPM_BUILD_ROOT%{_libdir}
ln -s  /%{_lib}/libfipscheck.so.%{soversion} $RPM_BUILD_ROOT%{_libdir}/libfipscheck.so
rm $RPM_BUILD_ROOT/%{_lib}/libfipscheck.so

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc ChangeLog COPYING README AUTHORS
%{_bindir}/fipscheck
%{_bindir}/.fipscheck.hmac
%{_bindir}/fipshmac

%files -n %lname
%defattr(-,root,root,-)
/%{_lib}/libfipscheck.so.*
/%{_lib}/.libfipscheck.so.*
%{_mandir}/man8/*.8.gz

%files devel
%defattr(-,root,root,-)
%{_includedir}/fipscheck.h
%{_libdir}/libfipscheck.so
%{_mandir}/man3/*.3.gz

%changelog
* Mon Sep 16 2019 Vítězslav Čížek <vcizek@suse.com>
- Remove #include of unused fips.h to fix build with OpenSSL 1.1.1
  (bsc#1149792)
  * add fipscheck-fips.h_not_needed.patch
* Mon Jun 12 2017 daniel.molkentin@suse.com
- Port to OpenSSL 1.1 (bsc#1042649)
  Adds openssl-1_1-port.patch
* Mon Apr 13 2015 jengelh@inai.de
- Set RPM groups anew. Drop implicit cleaning parts.
* Mon Jun  2 2014 meissner@suse.com
- add baselibs.conf
* Tue May 27 2014 meissner@suse.com
- updated to 1.4.1
  - added manpages
  - fipscheck/fipshmac: Add -s option to specify the hmac suffix
  - fipshmac: Add '-d' option to specify where to put the .hmac files
  - various bugfixes
* Tue Jan 21 2014 cfarrell@suse.com
- license update: BSD-2-Clause
  See LICENSE
* Mon Jan 20 2014 meissner@suse.com
- imported a generic fips helper to verify fips modules, linked
  to openssl.
